Installation instructions
=========================

Dependencies
------------

``galsampler`` requires `numpy <https://numpy.org/>`__, `scipy <https://scipy.org/>`__,
and `numba <https://numba.pydata.org//>`__.

Installation
------------

``galsampler`` is available for installation via conda-forge:

.. code-block:: python

    conda install lsstdesc-galsampler

The package can be also installed by cloning the
`galsampler <https://github.com/LSSTDESC/galsampler/>`__ GitHub repository and running:

.. code-block:: python

    pip install .


However you install the code, to use it from a python interpreter:

    .. code-block:: python

        >>> import galsampler
